#
# spec file for package haveged
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{!?_udevrulesdir: %global _udevrulesdir %(pkg-config --variable=udevdir udev)/rules.d }
Name:           haveged
Version:        1.9.2
Release:        lp152.4.3
Summary:        Feed entropy into random pool
License:        GPL-3.0-only
Group:          System/Daemons
Url:            http://www.issihosts.com/haveged/
Source0:        http://www.issihosts.com/haveged/%{name}-%{version}.tar.gz
Source2:        %{name}.service
Source3:        90-haveged.rules
Source4:        haveged-dracut.module
Patch0:         ppc64le.patch
# PATCH-FIX-UPSTREAM: ent tests randomly fail so make them conditional tchvatal@suse.cz bnc#876674
Patch1:         haveged-conditional-enttest.patch
# PATCH-FIX-UPSTREAM: don't write to syslog at startup to avoid deadlocks psimons@suse.com bnc#959237
Patch3:         haveged-no-syslog.patch
# PATCH-FIX-GITHUB: Fix segfault on arm machines
Patch4:         f2193587.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(systemd)
BuildRequires:  pkgconfig(udev)
Requires(post): coreutils
Requires(postun): coreutils
Enhances:       apache2
Enhances:       gpg2
Enhances:       openssl
Enhances:       openvpn
Enhances:       php5
Enhances:       smtp_daemon
Enhances:       systemd
%{?systemd_requires}

%description
The haveged daemon feeds the linux entropy pool with random
numbers generated from hidden processor state.

For more informations see http://www.issihosts.com/haveged/

%package devel
Summary:        Haveged development files
Group:          Development/Libraries/C and C++
Requires:       libhavege1 = %{version}

%description devel
Headers and for the haveged library

This package contains the haveged implementation of the HAVEGE
algorithm and supporting features.

%package -n libhavege1
Summary:        Haveged interface library
Group:          System/Libraries

%description -n libhavege1
Shared object for the haveged library
This package contains the haveged implementation of the HAVEGE
algorithm and supporting features.

%prep
%setup -q
%patch0 -p1
%patch1 -p1
%patch3 -p1
%patch4 -p1

%build
autoreconf -fvi
export CFLAGS="%{optflags} -fpie"
export LDFLAGS="-Wl,-z,relro,-z,now -pie"
# ENT randomly fails so disable the test
%configure \
    --disable-static \
    --disable-enttest \
    --enable-nistest \
    --enable-daemon \
    --enable-clock_gettime
make %{?_smp_mflags}

%check
#XXX: nist test is killed by SIGKILL with static int random_pool1[_32MB] on
#     32bit. Let change it to _08MB to avoid the test beeing killed, even if I
#     am not sure allocate of 128M is prohibited
%ifarch %{ix86}
sed -i 's/\[_32MB\]/[_08MB]/' nist/nist.c
%endif

make %{?_smp_mflags} check

%install
%make_install
install -D -m0644 %{SOURCE2} %{buildroot}%{_unitdir}/%{name}.service
install -D -m0644 %{SOURCE3} %{buildroot}%{_udevrulesdir}/90-%{name}.rules
rm -f %{buildroot}%{_libdir}/libhavege.*a
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}

install -d -m0755 %{buildroot}%{_prefix}/lib/dracut/modules.d/98%{name}
install -m0755 %{SOURCE4} %{buildroot}%{_prefix}/lib/dracut/modules.d/98%{name}/module-setup.sh

%post
%{?udev_rules_update:%udev_rules_update}
%service_add_post %{name}.service
%{?regenerate_initrd_post}

%postun
%service_del_postun %{name}.service
%{?regenerate_initrd_post}

%posttrans
%{?regenerate_initrd_posttrans}

%pre
%service_add_pre %{name}.service

%preun
%service_del_preun %{name}.service

%post -n libhavege1 -p /sbin/ldconfig
%postun -n libhavege1 -p /sbin/ldconfig

%files
%license COPYING
%{_sbindir}/rc%{name}
%{_sbindir}/%{name}
%{_mandir}/man8/%{name}.8%{ext_man}
%{_unitdir}/%{name}.service
%{_udevrulesdir}/90-%{name}.rules
%dir %{_prefix}/lib/dracut
%dir %{_prefix}/lib/dracut/modules.d
%dir %{_prefix}/lib/dracut/modules.d/98%{name}
%{_prefix}/lib/dracut/modules.d/98%{name}/module-setup.sh

%files devel
%license COPYING
%{_mandir}/man3/libhavege.3%{ext_man}
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/havege.h
%doc contrib/build/havege_sample.c
%{_libdir}/*.so

%files -n libhavege1
%license COPYING
%{_libdir}/*.so.*

%changelog
* Wed Sep 19 2018 Dr. Werner Fink <werner@suse.de>
- Add patch f2193587.patch from github pull request (bsc#1134351)
  * Fix segfault on arm machines which do not eport the cache size
    or say it is -1 in sysfs
* Mon Mar 19 2018 kukuk@suse.de
- Use %%license instead of %%doc [bsc#1082318]
* Sun Feb 18 2018 avindra@opensuse.org
- update to 1.9.2
  * Cross compile fixes
  * Limit watermark max to less than pool size to avoid 100%% cpu
    condition
  * Add service.suse init script
- drop fix-enforced-clock-gettime.patch (fixed upstream)
- cleanup with spec-cleaner
* Sun Jun 19 2016 jengelh@inai.de
- reset rpm groups
* Fri Jun 17 2016 psimons@suse.com
- Add haveged-no-syslog.patch to remedy the potential for deadlocks
  when booting the system: journald reads from /dev/random, which
  receives entropy from haveged, which in turn logs to syslog
  before providing any. Ideally, haveged would provide a proper
  command-line flag to disable use of syslog. Will work with
  upstream to resolve this in a cleaner way. (bnc#959237)
- Remove "After=systemd-random-seed.service" from systemd service
  file to avoid the potential for deadlocks when booting the
  system: systemd-random-seed needs /var to read its previous
  state; mounting /var needs journald; journald needs entropy; and
  entropy is provided by haveged, which needs systemd-random-seed.
  (bnc#959237)
* Thu Dec 10 2015 tiwai@suse.de
- Fix missing dependency on coreutils for initrd macros (boo#958562)
* Fri Oct  9 2015 meissner@suse.com
- haveged.service: reverted the dependency on systemd-journald.socket
  for now, as it causes a dependency loop. bsc#949728 bsc#950857
* Wed Sep 30 2015 meissner@suse.com
- modules-setup.sh should be module-setup.sh in dracut, also 755
- add dependency on systemd-journald.socket to make haveged
  really start before journald in the initrd. bsc#898669
* Tue Sep 29 2015 dmueller@suse.com
- add fix-enforced-clock-gettime.patch to fix build on generic
  platforms like e.g. aarch64, which is only needed due to
  our (non-recommended choice) of using gettime (fate#318370)
* Tue Feb 17 2015 meissner@suse.com
- haveged-dracut.module: include haveged into the initrd for
  randomness generation. bsc#898669
- haveged.service: adjust so it is started before journald
  and also make sure it is shutdown quite late. bsc#898669
- regenerate initrd on installation. bsc#898669
* Fri Aug 29 2014 tchvatal@suse.com
- Adjust the service to start early enough for all usecases.
  Should fix bnc#892096.
* Tue Jun 10 2014 tchvatal@suse.com
- Disable haveged service on containers. bnc#881882
* Mon May 12 2014 tchvatal@suse.com
- Disable randomly failing ENT test bnc#876674
- Added patches:
  * haveged-conditional-enttest.patch
* Mon May 12 2014 tchvatal@suse.com
- Threads seem not to fix the random testsuite fail.
* Sat May 10 2014 crrodriguez@opensuse.org
- Fix "stop" of service, the daemon in foreground actually
  exits with a weird exit code. workaround this misbehaviour
  in the service file.
* Sat May 10 2014 crrodriguez@opensuse.org
- revert to non-forking service, "forking" services are racy
  and provided by systemd purely for compatibility with old daemons.
  see daemon(7) for the rationale. Only "simple" (default) and
  "notify" services must be used if possible.
- Also, there is no haveged.conf around, neither such file
  is parsed by the daemon at all.
- Start the daemon as soon as the random device is available with
  the help of udev, as starting services while starved of entropy
  is no good.
* Wed May  7 2014 tchvatal@suse.com
- Cleanup with spec-cleaner
- Adapt the service file to be forking and match what it does for
  me on Gentoo.
- Disable threads as they seem break some times.
- Capitalize summaries to make rpmlint happy.
* Tue Mar 11 2014 dvaleev@suse.com
- Add ppc64le support
- added patches:
  * ppc64le.patch
* Tue Feb 18 2014 crrodriguez@opensuse.org
- version 1.9.1
  * test suite improvements
  * man page updates
  * a few build tweaks
- restore rchaveged link
* Mon Jan  6 2014 mvyskocil@suse.com
- update to 1.8
  * Fix return code for signalled termination.
  * Update init.d/service.fedora - new return code + simple, not forking
  * Add --enable_unitdir as DESTDIR for systemd install
* Mon Jun 17 2013 mvyskocil@suse.com
- update to 1.7c
  * Correct additional run-time test aligment problems on mips.
  * Correct run-time test aligment problems on sparc and mips.
  * Correct ppc detection in build
    deprecates haveged-ppc.patch
- use correct Group for libhavege1
- haveged-devel requires libhavege1
* Sun May  5 2013 crrodriguez@opensuse.org
- Remove PrivateTmp=true here, haveged does not create temporary
  files, either directly or indirectly.
* Thu May  2 2013 crrodriguez@opensuse.org
- haveged 1.7a
  * Correct VPATH issues and modify check target to support
  parallel builds and changes in automake 1.13 test harness.
  Updated sample spec file and other documentation changes.
* Tue Mar 26 2013 mvyskocil@suse.com
- add autoconf to BuildRequires
- explain the need for autoreconf
- tag haveged-ppc.patch
* Wed Mar 20 2013 crrodriguez@opensuse.org
- Remove all sysvinit compatibility.
* Mon Jan 21 2013 ro@suse.de
- spit off devel package (all new files not present before)
- spit off library package to follow shared library policy
- update to 1.7
  * Add havege_status_dump() as basis for haveged diagnositics
  * Provide sample spec to build haveged and haveged-devel
  * Add contrib/build to provide build support
  * Modify build to use libtool
  * Retname base types to alias stdint.h types to allow 'fixes' if necessary
  * Rename all public functions to follow havege_* naming convention
  * Sanitize havege.h to be include file for devel package
  * Add destroy() to havege for library use.
  * Move all remaining static vars to allocated memory.
  * Rework include file structure to eliminate include sequence errors.
  * Fix (rare) segfault in test0 caused by 1.6 alignment fix
- update to  v1.6a
  * Fix typo in configure.ac
* Fri Dec 21 2012 dvaleev@suse.com
- fix powerpc detection (haveged-ppc.patch)
* Sun Dec 16 2012 pascal.bleser@opensuse.org
- update to 1.6:
  * make clock_gettime a build option and correct dependencies when used
  * fix alignment fault on arm64 in procedure A test0
* Mon Nov 26 2012 crrodriguez@opensuse.org
- Current version does support ARM, remove the ExcludeArch
* Mon Sep 24 2012 crrodriguez@opensuse.org
- Tight up systemd service file, this daemon does not
  need network and can use PrivateNetwork=yes
* Mon Aug 13 2012 mvyskocil@suse.cz
- Update to 1.5
  * Add online tests based on AIS-31
  * Add -p option to specify the pid location.
  * Fix -F option to not take argument - i.e. now a switch
  * Factor diagnostic methods for capture and inject for better performance
  * Fix install target, move to bin and eliminate script if not daemon, now use sysv and systemd templates
- use -F with no arguments in haveged.service
- work-around nist check on i586 by decreasing the size of static array in a test
* Tue May 15 2012 aboe@opensuse.org
- Update to version 1.4
  * Add s390 architecture. Thanks to Dan Horak and Jiri Hladky
  * Add generic architecture with clock_gettime() timer.
  * Rewrite collection loop to support multiple instances and new diagnostics
  * Rewrite tuning mechanism to add virtual file system mining and correct cpuid bugs
  * Add prototype multi-thread collection option
  * Reduce collection buffer size to .5MB
  * Improve/correct build and install
  * Add new invocation options to support new features.
- init script additions $remote_fs added
* Thu Feb  9 2012 crrodriguez@opensuse.org
- build with -fpie
* Sat Dec 31 2011 crrodriguez@opensuse.org
- Put the haveged binary back in /usr/sbin not in /sbin
* Wed Dec 14 2011 crrodriguez@opensuse.org
- Update to version 1.3.0a, PPC fixes.
- Cleanup systemd unit and drop capabiltities there.
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Tue Nov 29 2011 crrodriguez@opensuse.org
- Use proper systemd macros
- reduce verbosity level to the minimum
* Tue Nov 22 2011 crrodriguez@opensuse.org
- Use Service type "simple" in systemd unit
* Tue Nov  1 2011 ro@suse.de
- fix build on ia64, s390, s390x
* Tue Oct 25 2011 pascal.bleser@opensuse.org
- update to 1.3:
  * reorganized to allow its collection mechanism to be better accessed
    directly through the file system: includes the option to suppress the
    daemon interface in the build for circumstances where /dev/random is
    unavailable or its use is inappropriate
* Sat Oct  1 2011 crrodriguez@opensuse.org
- There is no support for arm targets here, may be fixable
  later.
* Sun Jul 24 2011 crrodriguez@opensuse.org
- Update to version 1.2.
* Mon Jun  6 2011 k0da@opensuse.org
- fix ppc64 build
* Mon Jun  6 2011 adrian@suse.de
- fix URL to source tar ball
* Sat May  7 2011 crrodriguez@opensuse.org
- Update to version 1.1, upstream version where the bugs
  present in old versions have been fixed in different ways.
* Tue Mar  1 2011 meissner@suse.de
- avoid unnecessary services. bnc#675841
  also the start should be mediated by YaST or kiwi depending
  on presence of a virtualization environment, not by the package
  itself.
* Tue Jan  4 2011 cristian.rodriguez@opensuse.org
- Update to version 0.9_git201101042303
  * fix wrong usage of strdupa
- fix build in older distros that have no XZ
* Tue Jan  4 2011 cristian.rodriguez@opensuse.org
- Fix build in older distros
- run spec cleaner
* Tue Dec  7 2010 coolo@novell.com
- prereq init script syslog
* Thu Nov 25 2010 cristian.rodriguez@opensuse.org
- Use gcc's __cpuid instead of homegrown asm.
* Tue Nov 23 2010 cristian.rodriguez@opensuse.org
- Fix optimization problem, actually a bug in inline asm
  code. avoid using it, instead try hard to use either
  GCC builtins or properly corrected inline asm.
  Thanks Richard for pointing to the right solution.
* Sat Nov  6 2010 aj@suse.de
- Package /lib/systemd/system/ and /lib/systemd to fix build
* Fri Nov  5 2010 cristian.rodriguez@opensuse.org
- Link with full RELRO (-Wl,-z,relro,-z,now)
* Wed Nov  3 2010 cristian.rodriguez@opensuse.org
- add systemd support
* Fri Sep 24 2010 cristian.rodriguez@opensuse.org
- Drop as much capabilitites as possible using libcap-ng
* Sat Jul 31 2010 cristian.rodriguez@opensuse.org
- I meant Enhances not Supplements
* Fri Jul 30 2010 cristian.rodriguez@opensuse.org
- Implement hack to start by default only in VMs
* Tue Jul 27 2010 cristian.rodriguez@opensuse.org
- Run the complete test suite (for the paranoid)
- use O_CLOEXEC on fds
* Tue Jul 20 2010 cristian.rodriguez@opensuse.org
- enable daemon by default
- add a few Supplements so the it gets installed automatically.
* Sun Jul 18 2010 cristian.rodriguez@opensuse.org
- add proper Requires(pre)
* Fri Jul 16 2010 cristian.rodriguez@opensuse.org
- build with no optimization, there are reports saying it
  may crash with -O1 like http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=563938
* Thu Jul 15 2010 cristian.rodriguez@opensuse.org
- move deamon to /sbin
- tune the spec file
- add a SUSE standard init script
* Fri May 28 2010 meissner@suse.de
- haveged 0.9
  Gather entropy by doing calculation and looking
  at secondary high resolution processor information
  (tsc, cache misses etc.)
